@@ -388,12 +388,28 @@ mc_args_new_color_group (void)
 static gchar *
 mc_args_add_usage_info (void)
 {
-    mc_args__loc__usage_string = g_strdup_printf ("[%s] %s\n %s - %s\n",
-                                                  _("+number"),
-                                                  _("[this_dir] [other_panel_dir]"),
-                                                  _("+number"),
-                                                  _
-                                                  ("Set initial line number for the internal editor"));
+    gchar *s;
+
+    switch (mc_global.mc_run_mode)
+    {
+    case MC_RUN_EDITOR:
+        s = g_strdup_printf ("%s\n", _("[+lineno] file1[:lineno] [file2[:lineno]...]"));
+        break;
+    case MC_RUN_VIEWER:
+        s = g_strdup_printf ("%s\n", _("file"));
+        break;
+#ifdef USE_DIFF_VIEW
+    case MC_RUN_DIFFVIEWER:
+        s = g_strdup_printf ("%s\n", _("file1 file2"));
+        break;
+#endif /* USE_DIFF_VIEW */
+    case MC_RUN_FULL:
+    default:
+        s = g_strdup_printf ("%s\n", _("[this_dir] [other_panel_dir]"));
+    }
+
+    mc_args__loc__usage_string = s;
+
     return mc_args__loc__usage_string;
 }
 
@@ -613,6 +629,32 @@ parse_mcedit_arguments (int argc, char **argv)
 /*** public functions ****************************************************************************/
 /* --------------------------------------------------------------------------------------------- */
 
+void
+mc_setup_run_mode (char **argv)
+{
+    const char *base;
+
+    base = x_basename (argv[0]);
+
+    if (strncmp (base, "mce", 3) == 0 || strcmp (base, "vi") == 0)
+    {
+        /* mce* or vi is link to mc */
+        mc_global.mc_run_mode = MC_RUN_EDITOR;
+    }
+    else if (strncmp (base, "mcv", 3) == 0 || strcmp (base, "view") == 0)
+    {
+        /* mcv* or view is link to mc */
+        mc_global.mc_run_mode = MC_RUN_VIEWER;
+    }
+#ifdef USE_DIFF_VIEW
+    else if (strncmp (base, "mcd", 3) == 0 || strcmp (base, "diff") == 0)
+    {
+        /* mcd* or diff is link to mc */
+        mc_global.mc_run_mode = MC_RUN_DIFFVIEWER;
+    }
+#endif /* USE_DIFF_VIEW */
+}
+
 gboolean
 mc_args_parse (int *argc, char ***argv, const char *translation_domain, GError ** mcerror)
 {
@@ -730,7 +772,6 @@ mc_args_show_info (void)
 gboolean
 mc_setup_by_args (int argc, char **argv, GError ** mcerror)
 {
-    const char *base;
     char *tmp;
 
     mc_return_val_if_error (mcerror, FALSE);
@@ -764,27 +805,8 @@ mc_setup_by_args (int argc, char **argv, GError ** mcerror)
         (void) vpath;
     }
 
-    base = x_basename (argv[0]);
     tmp = (argc > 0) ? argv[1] : NULL;
 
-    if (strncmp (base, "mce", 3) == 0 || strcmp (base, "vi") == 0)
-    {
-        /* mce* or vi is link to mc */
-        mc_global.mc_run_mode = MC_RUN_EDITOR;
-    }
-    else if (strncmp (base, "mcv", 3) == 0 || strcmp (base, "view") == 0)
-    {
-        /* mcv* or view is link to mc */
-        mc_global.mc_run_mode = MC_RUN_VIEWER;
-    }
-#ifdef USE_DIFF_VIEW
-    else if (strncmp (base, "mcd", 3) == 0 || strcmp (base, "diff") == 0)
-    {
-        /* mcd* or diff is link to mc */
-        mc_global.mc_run_mode = MC_RUN_DIFFVIEWER;
-    }
-#endif /* USE_DIFF_VIEW */
-
     switch (mc_global.mc_run_mode)
     {
     case MC_RUN_EDITOR:
