@@ -49,10 +49,10 @@
 #include "src/subshell/subshell.h"
 #endif
 #include "src/execute.h"        /* shell_execute */
+#include "src/usermenu.h"       /* expand_format */
 
 #include "midnight.h"           /* current_panel */
 #include "layout.h"             /* for command_prompt variable */
-#include "usermenu.h"           /* expand_format */
 #include "tree.h"               /* sync_tree() */
 
 #include "command.h"
