@@ -355,21 +355,7 @@ do_external_panelize (char *command)
     }
 
     current_panel->is_panelized = TRUE;
-
-    if (list->len == 0)
-        dir_list_init (list);
-    else if (IS_PATH_SEP (list->list[0].fname[0]))
-    {
-        vfs_path_t *vpath_root;
-        int ret;
-
-        vpath_root = vfs_path_from_str (PATH_SEP_STR);
-        panel_set_cwd (current_panel, vpath_root);
-        ret = mc_chdir (vpath_root);
-        vfs_path_free (vpath_root);
-
-        (void) ret;
-    }
+    panelize_absolutize_if_needed (current_panel);
 
     if (pclose (external) < 0)
         message (D_NORMAL, _("External panelize"), _("Pipe close failed"));
@@ -399,7 +385,6 @@ do_panelize_cd (WPanel * panel)
 
     list = &panel->dir;
     list->len = panelized_panel.list.len;
-    panel->is_panelized = TRUE;
 
     panelized_same = vfs_path_equal (panelized_panel.root_vpath, panel->cwd_vpath);
 
@@ -432,6 +417,10 @@ do_panelize_cd (WPanel * panel)
         list->list[i].sort_key = panelized_panel.list.list[i].sort_key;
         list->list[i].second_sort_key = panelized_panel.list.list[i].second_sort_key;
     }
+
+    panel->is_panelized = TRUE;
+    panelize_absolutize_if_needed (panel);
+
     try_to_select (panel, NULL);
 }
 
@@ -486,6 +475,44 @@ panelize_save_panel (WPanel * panel)
 
 /* --------------------------------------------------------------------------------------------- */
 
+/**
+ * Conditionally switches a panel's directory to "/" (root).
+ *
+ * If a panelized panel's listing contain absolute paths, this function
+ * sets the panel's directory to "/". Otherwise it does nothing.
+ *
+ * Rationale:
+ *
+ * This makes tokenized strings like "%d/%p" work. This also makes other
+ * places work where such naive concatenation is done in code (e.g., when
+ * pressing ctrl+shift+enter, for CK_PutCurrentFullSelected).
+ *
+ * When to call:
+ *
+ * You should always call this function after you populate the listing
+ * of a panelized panel.
+ */
+void
+panelize_absolutize_if_needed (WPanel * panel)
+{
+    const dir_list *const list = &panel->dir;
+
+    /* Note: We don't support mixing of absolute and relative paths, which is
+     * why it's ok for us to check only the 1st entry. */
+    if (list->len > 1 && g_path_is_absolute (list->list[1].fname))
+    {
+        vfs_path_t *root;
+
+        root = vfs_path_from_str (PATH_SEP_STR);
+        panel_set_cwd (panel, root);
+        if (panel == current_panel)
+            mc_chdir (root);
+        vfs_path_free (root);
+    }
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 void
 cd_panelize_cmd (void)
 {
