@@ -1,7 +1,7 @@
 /*
    Virtual File System: GNU Tar file system.
 
-   Copyright (C) 2000-2016
+   Copyright (C) 2000-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -388,6 +388,7 @@ cpio_create_entry (struct vfs_class *me, struct vfs_s_super *super, struct stat
         /* cppcheck-suppress syntaxError */
     case S_IFNAM:
 #endif
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
         if ((st->st_size != 0) && (st->st_rdev == 0x0001))
         {
             /* FIXME: representation of major/minor differs between */
@@ -395,6 +396,7 @@ cpio_create_entry (struct vfs_class *me, struct vfs_s_super *super, struct stat
             st->st_rdev = (unsigned) st->st_size;
             st->st_size = 0;
         }
+#endif
         break;
     default:
         break;
@@ -460,53 +462,72 @@ cpio_create_entry (struct vfs_class *me, struct vfs_s_super *super, struct stat
             entry->ino->st.st_mode = st->st_mode;
             entry->ino->st.st_uid = st->st_uid;
             entry->ino->st.st_gid = st->st_gid;
+#ifdef HAVE_STRUCT_STAT_ST_MTIM
+            entry->ino->st.st_atim = st->st_atim;
+            entry->ino->st.st_mtim = st->st_mtim;
+            entry->ino->st.st_ctim = st->st_ctim;
+#else
             entry->ino->st.st_atime = st->st_atime;
             entry->ino->st.st_mtime = st->st_mtime;
             entry->ino->st.st_ctime = st->st_ctime;
+#endif
         }
 
         g_free (name);
     }
     else
     {                           /* !entry */
-        if (inode == NULL)
+        /* root == NULL can be in the following case:
+         * a/b/c -> d
+         * where 'a/b' is the stale link and therefore root of 'c' cannot be found in the archive
+         */
+        if (root != NULL)
         {
-            inode = vfs_s_new_inode (me, super, st);
-            if ((st->st_nlink > 0) && ((arch->type == CPIO_NEWC) || (arch->type == CPIO_CRC)))
+            if (inode == NULL)
             {
-                /* For case of hardlinked files */
-                defer_inode *i;
+                inode = vfs_s_new_inode (me, super, st);
+                if ((st->st_nlink > 0) && ((arch->type == CPIO_NEWC) || (arch->type == CPIO_CRC)))
+                {
+                    /* For case of hardlinked files */
+                    defer_inode *i;
 
-                i = g_new (defer_inode, 1);
-                i->inumber = st->st_ino;
-                i->device = st->st_dev;
-                i->inode = inode;
+                    i = g_new (defer_inode, 1);
+                    i->inumber = st->st_ino;
+                    i->device = st->st_dev;
+                    i->inode = inode;
 
-                arch->deferred = g_slist_prepend (arch->deferred, i);
+                    arch->deferred = g_slist_prepend (arch->deferred, i);
+                }
             }
+
+            if (st->st_size != 0)
+                inode->data_offset = CPIO_POS (super);
+
+            entry = vfs_s_new_entry (me, tn, inode);
+            vfs_s_insert_entry (me, root, entry);
         }
 
-        if (st->st_size != 0)
-            inode->data_offset = CPIO_POS (super);
-
-        entry = vfs_s_new_entry (me, tn, inode);
-        vfs_s_insert_entry (me, root, entry);
-
         g_free (name);
 
         if (!S_ISLNK (st->st_mode))
             CPIO_SEEK_CUR (super, st->st_size);
         else
         {
-            inode->linkname = g_malloc (st->st_size + 1);
-
-            if (mc_read (arch->fd, inode->linkname, st->st_size) < st->st_size)
+            if (inode != NULL)
             {
-                inode->linkname[0] = '\0';
-                return STATUS_EOF;
+                /* FIXME: do we must read from arch->fd in case of inode != NULL only or in any case? */
+
+                inode->linkname = g_malloc (st->st_size + 1);
+
+                if (mc_read (arch->fd, inode->linkname, st->st_size) < st->st_size)
+                {
+                    inode->linkname[0] = '\0';
+                    return STATUS_EOF;
+                }
+
+                inode->linkname[st->st_size] = '\0';    /* Linkname stored without terminating \0 !!! */
             }
 
-            inode->linkname[st->st_size] = '\0';        /* Linkname stored without terminating \0 !!! */
             CPIO_POS (super) += st->st_size;
             cpio_skip_padding (super);
         }
@@ -570,8 +591,13 @@ cpio_read_bin_head (struct vfs_class *me, struct vfs_s_super *super)
     st.st_nlink = u.buf.c_nlink;
     st.st_uid = u.buf.c_uid;
     st.st_gid = u.buf.c_gid;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
     st.st_rdev = u.buf.c_rdev;
+#endif
     st.st_size = (u.buf.c_filesizes[0] << 16) | u.buf.c_filesizes[1];
+#ifdef HAVE_STRUCT_STAT_ST_MTIM
+    st.st_atim.tv_nsec = st.st_mtim.tv_nsec = st.st_ctim.tv_nsec = 0;
+#endif
     st.st_atime = st.st_mtime = st.st_ctime = (u.buf.c_mtimes[0] << 16) | u.buf.c_mtimes[1];
 
     return cpio_create_entry (me, super, &st, name);
@@ -637,8 +663,13 @@ cpio_read_oldc_head (struct vfs_class *me, struct vfs_s_super *super)
     u.st.st_nlink = hd.c_nlink;
     u.st.st_uid = hd.c_uid;
     u.st.st_gid = hd.c_gid;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
     u.st.st_rdev = hd.c_rdev;
+#endif
     u.st.st_size = hd.c_filesize;
+#ifdef HAVE_STRUCT_STAT_ST_MTIM
+    u.st.st_atim.tv_nsec = u.st.st_mtim.tv_nsec = u.st.st_ctim.tv_nsec = 0;
+#endif
     u.st.st_atime = u.st.st_mtime = u.st.st_ctime = hd.c_mtime;
 
     return cpio_create_entry (me, super, &u.st, name);
@@ -713,8 +744,13 @@ cpio_read_crc_head (struct vfs_class *me, struct vfs_s_super *super)
     u.st.st_nlink = hd.c_nlink;
     u.st.st_uid = hd.c_uid;
     u.st.st_gid = hd.c_gid;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
     u.st.st_rdev = makedev (hd.c_rdev, hd.c_rdevmin);
+#endif
     u.st.st_size = hd.c_filesize;
+#ifdef HAVE_STRUCT_STAT_ST_MTIM
+    u.st.st_atim.tv_nsec = u.st.st_mtim.tv_nsec = u.st.st_ctim.tv_nsec = 0;
+#endif
     u.st.st_atime = u.st.st_mtime = u.st.st_ctime = hd.c_mtime;
 
     return cpio_create_entry (me, super, &u.st, name);
