@@ -203,6 +203,9 @@ sftpfs_lstat (const vfs_path_t * vpath, struct stat *buf, GError ** mcerror)
         buf->st_atime = attrs.atime;
         buf->st_mtime = attrs.mtime;
         buf->st_ctime = attrs.mtime;
+#ifdef HAVE_STRUCT_STAT_ST_MTIM
+        buf->st_atim.tv_nsec = buf->st_mtim.tv_nsec = buf->st_ctim.tv_nsec = 0;
+#endif
     }
 
     if ((attrs.flags & LIBSSH2_SFTP_ATTR_SIZE) != 0)
@@ -286,6 +289,9 @@ sftpfs_stat (const vfs_path_t * vpath, struct stat *buf, GError ** mcerror)
         buf->st_atime = attrs.atime;
         buf->st_mtime = attrs.mtime;
         buf->st_ctime = attrs.mtime;
+#ifdef HAVE_STRUCT_STAT_ST_MTIM
+        buf->st_atim.tv_nsec = buf->st_mtim.tv_nsec = buf->st_ctim.tv_nsec = 0;
+#endif
     }
 
     if ((attrs.flags & LIBSSH2_SFTP_ATTR_SIZE) != 0)
